==> janrain_connect-8.x-2.0.tar.gz: janrain_connect/src/Service/JanrainConnectConnector.php <==
<?php

namespace Drupal\janrain_connect\Service;

use Drupal\Core\Url;
use Drupal\janrain_connect\Constants\JanrainConnectWebServiceConstants;
use Drupal\janrain_connect\Constants\JanrainConnectConstants;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Config\ConfigFactory;
use JanrainRest\JanrainRest as Janrain;

/**
 * JanrainConnect Flow Class.
 */
class JanrainConnectConnector {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $config;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $janrainConnectValidate;

  /**
   * The Janrain core library object.
   *
   * @var \Janrain\Janrain
   */
  protected $janrainApi;

  /**
   * JanrainConnector constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactory $config_factory
   *   Config Factory.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   Language Manager.
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   Logger Factory.
   * @param \Drupal\janrain_connect\Service\JanrainConnectValidate $janrain_connect_validate
   *   JanrainConnect validate.
   */
  public function __construct(
    ConfigFactory $config_factory,
    LanguageManagerInterface $language_manager,
    LoggerChannelFactoryInterface $logger_factory,
    JanrainConnectValidate $janrain_connect_validate
  ) {
    $this->config = $config_factory->get('janrain_connect.settings');
    $this->janrainConnectValidate = $janrain_connect_validate;

    // Figure out which language to use.
    // Default is en-US.
    $locale = $this->config->get('default_language');
    $lid = $language_manager->getCurrentLanguage()->getId();
    $language = $this->config->get('flow_language_mapping_' . $lid);
    if ($language) {
      $locale = $language;
    }

    // This object is the interface to perform calls to Janrain API.
    // Empty parameters are full_login credentials we will not use. They have
    // administrative rights and should be used with care.
    $this->janrainApi = new Janrain(
      $this->config->get('capture_server_url'),
      $this->config->get('config_server'),
      $this->config->get('flowjs_url'),
      '',
      '',
      $this->config->get('client_id'),
      $this->config->get('client_secret'),
      $this->config->get('application_id'),
      $locale,
      $this->config->get('flow_name'),
      $logger_factory->get('janrain_connect')
    );
  }

  /**
   * Register User on Janrain.
   *
   * @param array $data
   *   Array with Data.
   * @param string $redirect_uri
   *   Redirect URL.
   *
   * @return mixed
   *   Return janrain result using janrainCalls.
   */
  public function register(array $data, $redirect_uri = NULL) {
    if (!$redirect_uri) {
      $redirect_uri = Url::fromRoute('<front>', [], ['absolute' => TRUE])->toString();
    }

    $result = $this->janrainApi->registerNativeTraditional(
      $this->config->get('client_id'),
      $this->config->get('flow_version'),
      $redirect_uri,
      JanrainConnectWebServiceConstants::JANRAIN_CONNECT_FORM_REGISTRATION,
      $data
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Social Registrate User on Janrain.
   *
   * @param string $engageToken
   *   Social engage token.
   * @param array $data
   *   Array with Data.
   * @param string $redirect_uri
   *   Redirect URL.
   *
   * @return mixed
   *   Return janrain result using janrainCalls.
   */
  public function socialRegister(string $engageToken, array $data, $redirect_uri = NULL) {
    if (!$redirect_uri) {
      $redirect_uri = Url::fromRoute('<front>', [], ['absolute' => TRUE])->toString();
    }

    $result = $this->janrainApi->registerNative(
      $this->config->get('client_id'),
      $this->config->get('flow_version'),
      $redirect_uri,
      JanrainConnectWebServiceConstants::JANRAIN_CONNECT_SOCIAL_FORM_SIGNIN,
      $engageToken,
      $data
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Login User on Janrain.
   *
   * @param string $email
   *   Email.
   * @param string $password
   *   Password.
   * @param string $mergeToken
   *   Social merge token.
   *
   * @return array
   *   Janrain api return.
   */
  public function login($email, $password, $mergeToken = NULL) {
    $data = [
      'signInEmailAddress' => $email,
      'currentPassword' => $password,
    ];

    if ($mergeToken) {
      $data['merge_token'] = $mergeToken;
    }

    $result = $this->janrainApi->authNativeTraditional(
      $this->config->get('client_id'),
      $this->config->get('flow_version'),
      $this->config->get('app_url'),
      JanrainConnectWebServiceConstants::JANRAIN_CONNECT_FORM_SIGNIN,
      $data
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Login User on Janrain.
   *
   * @param string $engageToken
   *   Engage token.
   * @param string $mergeToken
   *   Engage merge token.
   * @param string $redirect
   *   Redirect Url.
   *
   * @return array
   *   Janrain api return.
   */
  public function socialLogin($engageToken, $mergeToken, $redirect) {
    $result = $this->janrainApi->authNative(
      $this->config->get('client_id'),
      $this->config->get('flow_version'),
      $redirect,
      JanrainConnectWebServiceConstants::JANRAIN_CONNECT_SOCIAL_FORM_SIGNIN,
      $engageToken,
      $mergeToken
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Get list of active social providers.
   *
   * @param string $provider
   *   Social media id.
   * @param string $redirect
   *   Redirect Url.
   * @param string $locale
   *   Language like en-us.
   *
   * @return string
   *   Given provider's login URL.
   */
  public function getSocialProviders($provider, $redirect, $locale) {
    return $this->janrainApi->socialLoginUrl($provider, $redirect, $locale);
  }

  /**
   * Get user data from Entity Api.
   *
   * @param string $accessToken
   *   Access Token.
   */
  public function getUserData($accessToken) {
    $result = $this->janrainApi->entity($accessToken, 'user');

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Janrain Forgot Password.
   *
   * @param string $email
   *   Email.
   * @param string $redirect_uri
   *   Redirect URI.
   */
  public function forgotPassword($email, $redirect_uri = NULL) {
    if (!$redirect_uri) {
      $redirect_uri = Url::fromRoute('<front>', [], ['absolute' => TRUE])->toString();
    }

    $data = [
      'signInEmailAddress' => $email,
    ];

    $result = $this->janrainApi->forgotPasswordNative(
      $this->config->get('client_id'),
      $this->config->get('flow_version'),
      $redirect_uri,
      JanrainConnectWebServiceConstants::JANRAIN_CONNECT_FORM_FORGOT_PASSWORD,
      $data
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Get Verification Code.
   *
   * @param string $uuid
   *   UUID.
   */
  public function getVerificationCode($uuid) {
    $result = $this->janrainApi->getVerificationCode(
      $uuid,
      'user',
      'emailVerified'
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Change Password.
   *
   * @param string $actual_password
   *   Actual Password.
   * @param string $new_password
   *   New Password.
   * @param string $new_password_confirm
   *   Confirmation for New Password.
   * @param string $token
   *   Access Token.
   */
  public function changePassword($actual_password, $new_password, $new_password_confirm, $token) {
    // If user is not logged by Janrain, there is no token.
    if (!$token) {
      return [
        'has_errors' => TRUE,
        JanrainConnectWebServiceConstants::JANRAIN_CONNECT_ERROR_DESCRIPTION => JanrainConnectConstants::JANRAIN_CONNECT_CHANGE_PASSWORD_GENERIC_ERROR,
      ];
    }

    $data = [
      'currentPassword' => $actual_password,
      'newPassword' => $new_password,
      'newPasswordConfirm' => $new_password_confirm,
    ];

    // Token will be NULL if user didn't signin via Janrain.
    $result = $this->janrainApi->updateProfileNative(
      $this->config->get('client_id'),
      $this->config->get('flow_version'),
      JanrainConnectWebServiceConstants::JANRAIN_CONNECT_FORM_CHANGE_PASSWORD,
      $token,
      $data
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Update a user profile in Janrain.
   *
   * @param string $accessToken
   *   Access token provided when user is logged in.
   * @param array $data
   *   User data to be updated.
   *
   * @return array
   *   Janrain response.
   */
  public function updateUserProfile($accessToken, array $data) {
    // If user is not logged by Janrain, there is no token.
    if (!$accessToken) {
      return [
        'has_errors' => TRUE,
        JanrainConnectWebServiceConstants::JANRAIN_CONNECT_ERROR_DESCRIPTION => JanrainConnectConstants::JANRAIN_CONNECT_CHANGE_PASSWORD_GENERIC_ERROR,
      ];
    }

    $result = $this->janrainApi->updateProfileNative(
      $this->config->get('client_id'),
      $this->config->get('flow_version'),
      JanrainConnectWebServiceConstants::JANRAIN_CONNECT_FORM_EDIT_PROFILE,
      $accessToken,
      $data
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

}

==> janrain_connect-8.x-2.4.tar.gz: janrain_connect/src/Service/JanrainConnectConnector.php <==
<?php

namespace Drupal\janrain_connect\Service;

use Drupal\Core\Url;
use Drupal\janrain_connect\Constants\JanrainConnectWebServiceConstants;
use Drupal\janrain_connect\Constants\JanrainConnectConstants;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Config\ConfigFactory;
use JanrainRest\JanrainRest as Janrain;
use Psr\Log\LoggerInterface;

/**
 * JanrainConnect Flow Class.
 */
class JanrainConnectConnector {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $config;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $janrainConnectValidate;

  /**
   * The Janrain core library object.
   *
   * @var \Janrain\Janrain
   */
  protected $janrainApi;

  /**
   * JanrainConnector constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactory $config_factory
   *   Config Factory.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   Language Manager.
   * @param \Psr\Log\LoggerInterface $logger
   *   A logger instance.
   * @param \Drupal\janrain_connect\Service\JanrainConnectValidate $janrain_connect_validate
   *   JanrainConnect validate.
   */
  public function __construct(
    ConfigFactory $config_factory,
    LanguageManagerInterface $language_manager,
    LoggerInterface $logger,
    JanrainConnectValidate $janrain_connect_validate
  ) {
    $this->config = $config_factory->get('janrain_connect.settings');
    $this->janrainConnectValidate = $janrain_connect_validate;

    // Figure out which language to use.
    // Default is en-US.
    $locale = $this->config->get('default_language');
    $lid = $language_manager->getCurrentLanguage()->getId();
    $language = $this->config->get('flow_language_mapping_' . $lid);
    if ($language) {
      $locale = $language;
    }

    // This object is the interface to perform calls to Janrain API.
    // Empty parameters are full_login credentials we will not use. They have
    // administrative rights and should be used with care.
    $this->janrainApi = new Janrain(
      $this->config->get('capture_server_url'),
      $this->config->get('config_server'),
      $this->config->get('flowjs_url'),
      '',
      '',
      $this->config->get('client_id'),
      $this->config->get('client_secret'),
      $this->config->get('application_id'),
      $locale,
      $this->config->get('flow_name'),
      $logger
    );
  }

  /**
   * Register User on Janrain.
   *
   * @param array $data
   *   Array with Data.
   * @param string $redirect_uri
   *   Redirect URL.
   *
   * @return mixed
   *   Return janrain result using janrainCalls.
   */
  public function register(array $data, $redirect_uri = NULL) {
    if (!$redirect_uri) {
      $redirect_uri = Url::fromRoute('<front>', [], ['absolute' => TRUE])->toString();
    }

    $result = $this->janrainApi->registerNativeTraditional(
      $this->config->get('client_id'),
      $this->config->get('flow_version'),
      $redirect_uri,
      JanrainConnectWebServiceConstants::JANRAIN_CONNECT_FORM_REGISTRATION,
      $data
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Social Registrate User on Janrain.
   *
   * @param string $engageToken
   *   Social engage token.
   * @param array $data
   *   Array with Data.
   * @param string $redirect_uri
   *   Redirect URL.
   *
   * @return mixed
   *   Return janrain result using janrainCalls.
   */
  public function socialRegister(string $engageToken, array $data, $redirect_uri = NULL) {
    if (!$redirect_uri) {
      $redirect_uri = Url::fromRoute('<front>', [], ['absolute' => TRUE])->toString();
    }

    $result = $this->janrainApi->registerNative(
      $this->config->get('client_id'),
      $this->config->get('flow_version'),
      $redirect_uri,
      JanrainConnectWebServiceConstants::JANRAIN_CONNECT_SOCIAL_FORM_SIGNIN,
      $engageToken,
      $data
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Login User on Janrain.
   */
  public function login($data, $mergeToken = NULL) {

    if ($mergeToken) {
      $data['merge_token'] = $mergeToken;
    }

    $result = $this->janrainApi->authNativeTraditional(
      $this->config->get('client_id'),
      $this->config->get('flow_version'),
      $this->config->get('app_url'),
      JanrainConnectWebServiceConstants::JANRAIN_CONNECT_FORM_SIGNIN,
      $data
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Login User on Janrain.
   *
   * @param string $engageToken
   *   Engage token.
   * @param string $mergeToken
   *   Engage merge token.
   * @param string $redirect
   *   Redirect Url.
   *
   * @return array
   *   Janrain api return.
   */
  public function socialLogin($engageToken, $mergeToken, $redirect) {
    $result = $this->janrainApi->authNative(
      $this->config->get('client_id'),
      $this->config->get('flow_version'),
      $redirect,
      JanrainConnectWebServiceConstants::JANRAIN_CONNECT_SOCIAL_FORM_SIGNIN,
      $engageToken,
      $mergeToken
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Get list of active social providers.
   *
   * @param string $provider
   *   Social media id.
   * @param string $redirect
   *   Redirect Url.
   * @param string $locale
   *   Language like en-us.
   *
   * @return string
   *   Given provider's login URL.
   */
  public function getSocialProviders($provider, $redirect, $locale) {
    return $this->janrainApi->socialLoginUrl($provider, $redirect, $locale);
  }

  /**
   * Get user data from Entity Api.
   *
   * @param string $accessToken
   *   Access Token.
   */
  public function getUserData($accessToken) {
    $result = $this->janrainApi->entity($accessToken, 'user');

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Janrain Forgot Password.
   *
   * @param string $email
   *   Email.
   * @param string $redirect_uri
   *   Redirect URI.
   */
  public function forgotPassword($email, $redirect_uri = NULL) {
    if (!$redirect_uri) {
      $redirect_uri = Url::fromRoute('<front>', [], ['absolute' => TRUE])->toString();
    }

    $data = [
      'signInEmailAddress' => $email,
    ];

    $result = $this->janrainApi->forgotPasswordNative(
      $this->config->get('client_id'),
      $this->config->get('flow_version'),
      $redirect_uri,
      JanrainConnectWebServiceConstants::JANRAIN_CONNECT_FORM_FORGOT_PASSWORD,
      $data
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Get Verification Code.
   *
   * @param string $uuid
   *   UUID.
   */
  public function getVerificationCode($uuid) {
    $result = $this->janrainApi->getVerificationCode(
      $uuid,
      'user',
      'emailVerified'
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Change Password.
   *
   * @param string $actual_password
   *   Actual Password.
   * @param string $new_password
   *   New Password.
   * @param string $new_password_confirm
   *   Confirmation for New Password.
   * @param string $token
   *   Access Token.
   */
  public function changePassword($actual_password, $new_password, $new_password_confirm, $token) {
    // If user is not logged by Janrain, there is no token.
    if (!$token) {
      return [
        'has_errors' => TRUE,
        JanrainConnectWebServiceConstants::JANRAIN_CONNECT_ERROR_DESCRIPTION => JanrainConnectConstants::JANRAIN_CONNECT_CHANGE_PASSWORD_GENERIC_ERROR,
      ];
    }

    $data = [
      'currentPassword' => $actual_password,
      'newPassword' => $new_password,
      'newPasswordConfirm' => $new_password_confirm,
    ];

    // Token will be NULL if user didn't signin via Janrain.
    $result = $this->janrainApi->updateProfileNative(
      $this->config->get('client_id'),
      $this->config->get('flow_version'),
      JanrainConnectWebServiceConstants::JANRAIN_CONNECT_FORM_CHANGE_PASSWORD,
      $token,
      $data
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Entity Update.
   */
  public function entityUpdate($email, $value, $client_id = FALSE, $client_secret = FALSE) {

    if (empty($client_id)) {
      $client_id = $this->config->get('client_id');
    }

    if (empty($client_secret)) {
      $client_secret = $this->config->get('client_secret');
    }

    $type_name = $this->config->get('entity_type');

    $result = $this->janrainApi->entityUpdate(FALSE, FALSE, $type_name, $email, $value, $client_id, $client_secret);

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

  /**
   * Update a user profile in Janrain.
   *
   * @param string $accessToken
   *   Access token provided when user is logged in.
   * @param array $data
   *   User data to be updated.
   *
   * @return array
   *   Janrain response.
   */
  public function updateUserProfile($accessToken, array $data) {
    // If user is not logged by Janrain, there is no token.
    if (!$accessToken) {
      return [
        'has_errors' => TRUE,
        JanrainConnectWebServiceConstants::JANRAIN_CONNECT_ERROR_DESCRIPTION => JanrainConnectConstants::JANRAIN_CONNECT_CHANGE_PASSWORD_GENERIC_ERROR,
      ];
    }

    $result = $this->janrainApi->updateProfileNative(
      $this->config->get('client_id'),
      $this->config->get('flow_version'),
      JanrainConnectWebServiceConstants::JANRAIN_CONNECT_FORM_EDIT_PROFILE,
      $accessToken,
      $data
    );

    $this->janrainConnectValidate->validateResponse($result);

    return $result;
  }

}
